package io;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import model.Drawing;
import render.GraphicDevice;
import core.Rectangle;

public class StandardImageSavers implements Saver {

	private String format;
	private int type;

	private StandardImageSavers(String format, int imageType) {
		this.format = format;
		this.type = imageType;
	}

	@Override
	public void save(Drawing document, String to) {
		Rectangle bounds = document.getBounds();
		BufferedImage image = new BufferedImage(bounds.getWidth(),
				bounds.getHeight(), type);

		document.draw(new GraphicDevice(image.createGraphics()));

		try {
			ImageIO.write(image, format, new File(to));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	public static void register(Service io) {
		io.registerSaver("jpg", new StandardImageSavers("jpg",
				BufferedImage.TYPE_INT_RGB));
		io.registerSaver("bmp", new StandardImageSavers("bmp",
				BufferedImage.TYPE_INT_RGB));
		io.registerSaver("png", new StandardImageSavers("png",
				BufferedImage.TYPE_INT_ARGB));
	}

}
